<?php
/**
 * This file contains Class to manage the pointer position for tour.
 *
 * @package miniOrange_LDAP_AD_Integration
 * @subpackage Main
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
if ( ! class_exists( 'MO_LDAP_Pointer_Manager' ) ) {
	/**
	 * MO_LDAP_Pointer_Manager
	 */
	class MO_LDAP_Pointer_Manager {

		/**
		 * Var ptr_file
		 *
		 * @var string
		 */
		private $ptr_file;

		/**
		 * Var ptr_version
		 *
		 * @var string
		 */
		private $ptr_version;

		/**
		 * Var prefx
		 *
		 * @var string
		 */
		private $prefx;

		/**
		 * Var ptr
		 *
		 * @var array
		 */
		private $ptr;

		/**
		 * __construct
		 *
		 * @param  string $file : File object.
		 * @param  string $ptr_version : version.
		 * @param  string $prefx : prefix of tour section.
		 * @return void
		 */
		public function __construct( $file, $ptr_version, $prefx ) {
			$this->ptr_file    = file_exists( $file ) ? $file : false;
			$this->ptr_version = str_replace( '.', '_', $ptr_version );
			$this->prefx       = $prefx;
		}

		/**
		 * Function parse
		 *
		 * @return void
		 */
		public function parse() {
			if ( empty( $this->ptr_file ) ) {
				return;
			}
			$ptr = (array) require_once $this->ptr_file;
			if ( empty( $ptr ) ) {
				return;
			}
			foreach ( $ptr as $i => $pointer ) {
				$pointer['id']               = "{$this->prefx}{$this->ptr_version}_{$i}";
				$this->ptr[ $pointer['id'] ] = (object) $pointer;
			}
		}

		/**
		 * Function filter
		 *
		 * @param  string $page : page being parsed for tour.
		 * @return array
		 */
		public function filter( $page ) {
			if ( empty( $this->ptr ) ) {
				return array();
			}
			$userid     = get_current_user_id();
			$meta_data  = explode( ',', (string) get_user_meta( $userid, 'dismissed_wp_pointers', true ) );
			$active_ids = array_diff( array_keys( $this->ptr ), $meta_data );
			$info       = array();
			foreach ( $this->ptr as $i => $pointer ) {
				if (
				in_array( $i, $active_ids, true )
				&& isset( $pointer->where )
				&& in_array( $page, (array) $pointer->where, true )
				) {
					$info[] = $pointer;
				}
			}
			$counter = count( $info );

			if ( 0 === $info ) {
				return array();
			}
			foreach ( array_values( $info ) as $i => $pointer ) {
				$info[ $i ]->next = $i + 1 < $counter ? $info[ $i + 1 ]->id : '';
			}

			return $info;
		}
	}
}
