<?php
/**
 * This file renders user authentication reports table.
 *
 * @package miniOrange_LDAP_AD_Integration
 * @subpackage Main
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

if ( ! class_exists( 'MO_LDAP_User_Auth_Reports' ) ) {
	/**
	 * MO_LDAP_User_Auth_Reports : This Class contains function for LDAP authentication reports.
	 */
	class MO_LDAP_User_Auth_Reports extends WP_List_Table {

		/**
		 * __construct
		 *
		 * @return void
		 */
		public function __construct() {

			parent::__construct(
				array(
					'singular' => __( 'User', 'ldap' ),
					'plural'   => __( 'Users', 'ldap' ),
					'ajax'     => false,
				)
			);

		}

		/**
		 * Function get_users : get user authentication reports.
		 *
		 * @param  mixed $per_page Entries on each page.
		 * @param  mixed $page_number Current page to display.
		 * @return array
		 */
		public static function get_users( $per_page, $page_number ) {

			global $wpdb;

			$order_by = 'time';
			$order    = 'asc';
			if ( ! empty( $_GET['orderby'] ) ) { //phpcs:ignore WordPress.Security.NonceVerification.Recommended -- fetching GET parameter for changing table layout.

				$order_by = sanitize_text_field( wp_unslash( $_GET['orderby'] ) ); //phpcs:ignore WordPress.Security.NonceVerification.Recommended -- fetching GET parameter for changing table layout.
				if ( ! empty( $_GET['order'] ) ) { //phpcs:ignore WordPress.Security.NonceVerification.Recommended -- fetching GET parameter for changing table layout.
					$order = sanitize_text_field( wp_unslash( $_GET['order'] ) ); //phpcs:ignore WordPress.Security.NonceVerification.Recommended -- fetching GET parameter for changing table layout.
				}
			}
			$wp_user_reports_pagination_cache = wp_cache_get( 'wp_user_reports_pagination_cache' );
			if ( $wp_user_reports_pagination_cache ) {
				$result = $wp_user_reports_pagination_cache;
			} else {
				$result = $wpdb->get_results( //phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery -- Fetching data from a custom table.
					$wpdb->prepare( "SELECT * FROM {$wpdb->prefix}user_report ORDER BY %1s %1s LIMIT %d OFFSET %d", array( $order_by, $order, $per_page, ( $page_number - 1 ) * $per_page ) ), //phpcs:ignore WordPress.DB.PreparedSQLPlaceholders.UnquotedComplexPlaceholder -- Fetching data from a custom table.
					'ARRAY_A'
				);
				wp_cache_set( 'wp_user_reports_pagination_cache', $result );
			}

			$total_records = count( $result );
			for ( $i = 0;$i < $total_records;$i++ ) {
				$j                  = $i + 1;
				$result[ $i ]['id'] = (string) $j;
			}

			return $result;
		}

		/**
		 * Function record_count : Return the total number of records.
		 *
		 * @return int
		 */
		public static function record_count() {
			global $wpdb;
			$wp_user_reports_count_cache = wp_cache_get( 'mo_ldap_user_report_count_cache' );
			if ( $wp_user_reports_count_cache ) {
				return $wp_user_reports_count_cache;
			}
			$user_count = $wpdb->get_var( "SELECT COUNT(*) FROM {$wpdb->prefix}user_report" ); //phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery -- Fetching data from a custom table.
			wp_cache_set( 'mo_ldap_user_report_count_cache', $user_count );
			return $user_count;
		}

		/**
		 * Function column_default : Default column name.
		 *
		 * @param  mixed $item Item.
		 * @param  mixed $column_name Name of the column.
		 * @return string
		 */
		public function column_default( $item, $column_name ) {
			switch ( $column_name ) {
				case 'id':
				case 'user_name':
				case 'time':
				case 'ldap_status':
				case 'ldap_error':
					return $item[ $column_name ];
			}
		}

		/**
		 * Function get_columns : Get columns.
		 *
		 * @return array
		 */
		public function get_columns() {
			return array(
				'id'          => __( 'Sr No.' ),
				'user_name'   => __( 'Username' ),
				'time'        => __( 'Time <br>(UTC + 0)' ),
				'ldap_status' => __( 'Status' ),
				'ldap_error'  => __( 'Additional Information' ),
			);
		}

		/**
		 * Function get_sortable_columns : Get sortable columns.
		 *
		 * @return array
		 */
		public function get_sortable_columns() {
			return array(
				'user_name' => array( 'user_name', true ),
				'time'      => array( 'time', true ),
			);
		}

		/**
		 * Function prepare_items : Prepare items.
		 *
		 * @return void
		 */
		public function prepare_items() {

			$this->_column_headers = $this->get_column_info();

			$per_page     = $this->get_items_per_page( 'Users_per_page', 10 );
			$current_page = $this->get_pagenum();
			$total_items  = self::record_count();

			$this->set_pagination_args(
				array(
					'total_items' => $total_items,
					'per_page'    => $per_page,
				)
			);

			$this->items = self::get_users( $per_page, $current_page );
		}

	}
}
